from django.conf import settings
from django.core.cache import cache
from django.db import models

from common.java import JavaInterface, Callback, logging

import hashlib
import jpype

java = JavaInterface()

class RuleManager(object):
    def add(self, event):
        id = java.XAuditingMng.addArchiveRuleXATI('@%s' % event, java.certificate)
        logging.info('Created auditing rule: %s' % id)
        
        return id
    
    def cancel(self, rule):
        logging.info('Canceling auditing rule: %s' % rule)
        java.XAuditingMng.cancelArchiveRule(rule, java.certificate)
    
    def list(self):
        rules = java.XAuditingMng.getArchivingRulesXATI(java.certificate)
        values = rules.values()
        keys = rules.keySet()
        data = []
        
        for key, value in zip(keys, values):
            data.append({
                'rule': key, 
                'query': value
            })

        return data

class DataManager(object):
    def query(self, sql):        
        records = java.XAuditingMng.queryXATI(sql, java.certificate)
        logging.info('Executing query: %s' % sql)
        
        data = []
        keys = []
        
        for record in records:
            temp = record.toString().strip()
            temp = temp.replace('[', '')
            temp = temp.replace(']', '')

            try:
                if temp.index('='):
                    type = temp.split('=', 1)
                    values = type[1].split(',')
                    
                    row = {}
                    
                    for value in values:
                        single = value.split('=')
                        key = single[0].strip()
                        
                        row[key] = single[1].strip()
                        
                        if key not in keys:
                            keys.append(key)
                
                    data.append(row)
                    
            except ValueError:
                data.append({
                    'value': temp
                })
            
        return {
            'data': data, 
            'keys': keys
        }
