from django.conf import settings

from common.utils import JsonHttpResponse
from common.views import login_required
from auditing.models import DataManager, RuleManager

@login_required
def rules(request):
    data = { 'success': False }
    
    try:
        manager = RuleManager()
        data['data'] = manager.list()
        data['success'] = True
    except:
        import traceback
        traceback.print_exc()
    
    return JsonHttpResponse(data)

@login_required
def rules_add(request):
    handle = request.REQUEST.get('handle', None)
    data = { 'success': False }
    
    if handle:
        try:
            manager = RuleManager()
            data['data'] = manager.add(handle)
            data['success'] = True
        except:
            import traceback
            traceback.print_exc()
    
    return JsonHttpResponse(data)

@login_required
def rules_cancel(request):
    rules = request.REQUEST.get('rules', None)
    data = { 'success': False }

    if rules:
        manager = RuleManager()
        rules = rules.split(',')
        
        try:
            for rule in rules:
                manager.cancel(rule)
                data['success'] = True
        except:
            pass 
    
    return JsonHttpResponse(data)

@login_required
def data_query(request):
    sql = request.REQUEST.get('sql', None)
    data = { 'success': False }
    
    if sql:
        try:
            manager = DataManager()
            response = manager.query(sql)
            
            data['data'] = response['data']
            data['results'] = len(data['data'])
            data['success'] = True
            data['metaData'] = {
                'root': 'data',
                'successProperty': 'success',
                'fields': []
            }
            
            if len(response['keys']):
                for key in response['keys']:
                    data['metaData']['fields'].append({ 
                        'name': key, 
                        'header': key, 
                        'mapping': key,
                        'type': 'string'
                    })
            else:
                data['metaData']['fields'] = [{
                    'name': 'value',
                    'header': 'value',
                    'mapping': 'value',
                    'type': 'string'
                }]
        except:
            import traceback
            traceback.print_exc()


    return JsonHttpResponse(data)
