import os
import jpype
import logging

from django.conf import settings

class CertificateNotFound(Exception): pass
class JavaConnectionError(Exception): pass

logging.basicConfig()
logging.root.setLevel(logging.DEBUG)

classpath = [
    '/usr/share/tomcat5/webapps/volifecycle/WEB-INF/classes/',
    '/usr/share/java/auditingmng.jar',
    '/usr/share/java/DIXIMain.jar',
    '/usr/share/java/log4j.jar',
    '/usr/share/java/mina-core.jar',
    '/usr/share/java/mina-filter-ssl.jar',
    '/usr/share/java/monmng.jar',
    '/usr/share/java/slf4j-api.jar',
    '/usr/share/java/slf4j-log4j12.jar',
    '/usr/share/java/slf4j-simple.jar',
    '/usr/share/java/vops-backend.jar',
    '/usr/share/java/xati.jar',
    '/usr/share/java/xvoms.jar',
    '/usr/share/java/bcprov.jar',
    '/usr/share/java/mail.jar',
    '/usr/share/java/volife-cda.jar',
    '/usr/share/java/antlr.jar',
    '/usr/share/java/asm/asm.jar',
    '/usr/share/java/c3p0.jar',
    '/usr/share/java/cglib.jar',
    '/usr/share/java/commons-collections.jar',
    '/usr/share/java/dom4j.jar',
    '/usr/share/java/ehcache.jar',
    '/usr/share/java/hibernate3.jar',
    '/usr/share/java/jta.jar',
    '/usr/share/java/mysql-connector-java.jar',
    '/usr/share/java/commons-logging-adapters.jar',
    '/usr/share/java/comm_xml_schemas.jar',
    '/usr/share/java/vsuite-findbugs.jar',
    '/usr/share/java/commons-logging-api.jar',
    '/usr/share/java/commons-logging.jar',
    '/usr/share/java/jep.jar',
    '/usr/share/java/oncrpc.jar',
    '/usr/share/java/djep.jar',
    '/usr/share/java/junit4.jar',
    '/usr/share/java/java_cup.jar',
    '/usr/share/java/axis2-kernel.jar',
    '/usr/share/java/tools.jar',
    '/usr/share/java/XtreemFS.jar',
    '/usr/share/java/CdaUtil.jar',
    '/usr/share/java/cdaserver.jar',
    '/usr/share/java/CdaVO.jar',
    '/usr/share/java/security-services-vops.jar',
    '/usr/share/java/xmlrpc-common.jar',
    '/usr/share/java/xmlrpc-server.jar',
    '/usr/share/java/xmlrpc-client.jar',
    '/usr/share/java/xmldb.jar',
    '/usr/share/java/xmldb-svn.jar',
    '/usr/share/java/xmldb-api.jar',
    '/usr/share/java/excalibur-cli.jar',
    '/usr/share/java/stax-api.jar',
    '/usr/share/java/jgroups-all.jar',
    '/usr/share/java/sunxacml.jar',
    '/usr/share/java/jline.jar',
    '/usr/share/java/javax.servlet.jar',
    '/usr/share/java/ws-commons-util.jar',
    '/usr/share/java/commons-pool.jar',
    '/usr/share/java/jEdit-syntax.jar',
    '/usr/share/java/exist.jar',
    '/usr/share/java/eXist/quartz.jar',
    '/usr/share/java/eXist/exist-modules.jar',
    '/usr/share/java/eXist/exist-ngram-module.jar',
    '/usr/share/java/eXist/exist-optional.jar',
    '/usr/share/java/eXist/exist-fluent.jar',
    '/usr/share/java/eXist/resolver.jar',
    '/usr/share/java/eXist/serializer.jar',
    '/usr/share/java/eXist/xalan.jar',
    '/usr/share/java/eXist/xercesImpl.jar',
    '/usr/share/java/xml-apis.jar',
]

class JavaInterface(object):
    def __init__(self):
        self.initialized = False

    def __getattribute__(self, name):
        if not jpype.isJVMStarted():
            object.__getattribute__(self, 'init_JVM')()

        if not jpype.isThreadAttachedToJVM():
            jpype.attachThreadToJVM()
        
        if not object.__getattribute__(self, 'initialized'):
            object.__getattribute__(self, 'initialize')()

        return object.__getattribute__(self, name)

    def init_JVM(self):
        try:
            os.environ['HOME'] = settings.HOME_PATH
            cp = ':'.join(classpath)
            jpype.startJVM(settings.JAVA_HOME, '-Djava.class.path=%s'  % cp, '-DpathToRootSchemas=/usr/share/dixi/XMLExtractor/Schemas/')
        except:
            if not settings.DEBUG:
                raise JavaConnectionError()
        
            import traceback
            traceback.print_exc()
    
    def initialize(self):
        try:
            # You must use object.__getattribute__(self, 'name') instead of self.name because of __getattribute__
            self.initialized = True
            
            self.PropertyConfigurator = jpype.JClass('org.apache.log4j.PropertyConfigurator')
            object.__getattribute__(self, 'PropertyConfigurator').configure(settings.LOG4J_PROPERTIES)
            
            self.System = jpype.JClass('java.lang.System')
            self.File = jpype.JClass('java.io.File')
            self.Serializable = jpype.JClass('java.io.Serializable')
            self.Security = jpype.JClass('java.security.Security')
            self.X509Certificate = jpype.JClass('java.security.cert.X509Certificate')
            
            self.BouncyCastleProvider = jpype.JClass('org.bouncycastle.jce.provider.BouncyCastleProvider')
            self.XATI = jpype.JClass('eu.xtreemos.xati.XATI')
            self.XMonMng = jpype.JClass('eu.xtreemos.xati.API.XMonMng')
            self.ICallbackListener = jpype.JClass('eu.xtreemos.xosd.basic.ICallbackListener')
            self.Utils = jpype.JClass('eu.xtreemos.xosd.utilities.security.Utils')
            
            self.VOPS = jpype.JClass('eu.xtreemos.xosd.security.vops.VOPS')
            self.VOPSConfig = jpype.JClass('eu.xtreemos.security.vops.Conf')
            self.XVOPS = jpype.JClass('eu.xtreemos.xati.API.XVOPS') 
            
            self.XACMLConstants = jpype.JClass('eu.xtreemos.security.vops.xacml.utils.common.XACMLConstants')
            self.XACMLConstants.SubjectConstants = jpype.JClass('eu.xtreemos.security.vops.xacml.utils.common.XACMLConstants$SubjectConstants')
            self.XACMLConstants.ResourceConstants = jpype.JClass('eu.xtreemos.security.vops.xacml.utils.common.XACMLConstants$ResourceConstants')
            self.XACMLConstants.ResourceJSDLConstants = jpype.JClass('eu.xtreemos.security.vops.xacml.utils.common.XACMLConstants$ResourceJSDLConstants')
            self.XACMLConstants.ActionConstants = jpype.JClass('eu.xtreemos.security.vops.xacml.utils.common.XACMLConstants$ActionConstants')
            self.XACMLConstants.MonitoringConstants = jpype.JClass('eu.xtreemos.security.vops.xacml.utils.common.XACMLConstants$MonitoringConstants')

            self.IntegerMetric = jpype.JClass('eu.xtreemos.xosd.monmng.data.IntegerMetric')
            self.LongMetric = jpype.JClass('eu.xtreemos.xosd.monmng.data.LongMetric')
            self.FloatMetric = jpype.JClass('eu.xtreemos.xosd.monmng.data.FloatMetric')
            self.DoubleMetric = jpype.JClass('eu.xtreemos.xosd.monmng.data.DoubleMetric')
            self.StringMetric = jpype.JClass('eu.xtreemos.xosd.monmng.data.StringMetric')
            self.Event = jpype.JClass('eu.xtreemos.xosd.monmng.data.Event')

            self.XVOMSUtil = jpype.JClass('org.xtreemos.wp35.volifecycle.XVOMSUtil')
            self.XRCAServer = jpype.JClass('eu.xtreemos.xati.API.XRCAServer')
            self.VOException = jpype.JClass('org.xtreemos.wp35.volifecycle.VOException')
            
            self.XAuditingMng = jpype.JClass('eu.xtreemos.xati.API.XAuditingMng')
            
            self.XDaemon = jpype.JClass('eu.xtreemos.xati.API.XDaemon')
            self.XResourceMonitor = jpype.JClass('eu.xtreemos.xati.API.XResourceMonitor')
            self.SingleCommAddress = jpype.JClass('eu.xtreemos.system.communication.net.SingleCommAddress')
            self.CommunicationAddress = jpype.JClass('eu.xtreemos.system.communication.net.CommunicationAddress')
            
            object.__getattribute__(self, 'Security').addProvider(object.__getattribute__(self, 'BouncyCastleProvider')())

            if not os.path.exists(settings.CERTIFICATE_PATH):
                raise CertificateNotFound(settings.CERTIFICATE_PATH)

            self.certificate = object.__getattribute__(self, 'Utils').readX509Certificate(settings.CERTIFICATE_PATH, jpype.JArray(jpype.JChar)([]))
            self.xvoms_util = object.__getattribute__(self, 'XVOMSUtil')()
        except:
            if not settings.DEBUG:
                raise JavaConnectionError()
        
            import traceback
            traceback.print_exc()

class Callback(object):
    def callbackInvoked(self): 
        raise NotImplementedError()
    