from common.utils import JsonHttpResponse
from django import forms
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.views.decorators.cache import never_cache
from django.views.decorators.csrf import csrf_exempt
from django.shortcuts import render_to_response
from django.template.context import RequestContext

class AuthenticationForm(forms.Form):
    username = forms.CharField()
    password = forms.CharField(widget=forms.PasswordInput)

    def __init__(self, request=None, *args, **kwargs):
        self.request = request
        self.user = None
        super(AuthenticationForm, self).__init__(*args, **kwargs)

    def clean(self):
        from monitoring.models import authenticate
        
        username = self.cleaned_data.get('username')
        password = self.cleaned_data.get('password')

        if username and password:
            self.user = authenticate(username=username, password=password)
            
            if self.user is None:
                raise forms.ValidationError('Please enter a correct username and password.')

        return self.cleaned_data

    def get_user(self):
        return self.user

def login_required(func):
    def decorated(request, *args, **kwargs):
        if not 'user' in request.session:
            url = '%s' % reverse('login')
            
            return HttpResponseRedirect(url)
        
        return func(request, *args, **kwargs)
    
    return decorated

@login_required
def home(request):
    return render_to_response('home.html',
        context_instance=RequestContext(request)
    )
    
def login(request):
    return render_to_response('login.html',
       context_instance=RequestContext(request)
    )

@csrf_exempt
@never_cache
def login_json(request):
    try:
        result = {
            'success': False,
            'errors': 'Login failed. Try again.'
        }

        if request.method == 'POST':
            form = AuthenticationForm(data=request.POST)

            if form.is_valid():
                request.session.flush()
                request.session['user'] = form.get_user()

                result = {
                    'success': True
                }

        return JsonHttpResponse(result)
    except:
        import traceback
        traceback.print_exc()
        return JsonHttpResponse({
                    'success': False
                })

def logout(request, next_page=None):
    if 'user' in request.session:
        del request.session['user']
        request.session.flush()
    
    redirect_to = next_page if next_page else '/'
        
    return HttpResponseRedirect(redirect_to)
