from django.conf import settings
from django.core.cache import cache
from django.db import models

from common.java import JavaInterface, Callback, logging

import hashlib
import jpype

java = JavaInterface()

class NodesManager(object):
    nodes = None
    
    def get_nodes(self, services):
        self.nodes = java.XDaemon.getDaemons()
        values = []

        for node in self.nodes:
            try:
                address = node.getAdd()
                port = node.getPort()
                
                md5 = hashlib.md5()
                md5.update(address + str(port))
                node_id = md5.hexdigest()
                
                if not services or not self.has_service(node, node_id, services):
                    values.append({
                        'id': node_id,
                        'host': node.getStringHost(),
                        'address': node.toWholeAddress(),
                        'port': port
                    })
            except:
                continue

        return values  
    
    def get_node(self, node):
        values = []
        records = java.XResourceMonitor.queryResourceDescriptor(java.SingleCommAddress.parse(node))
        
        for record in records:
            values.append(dict(record.getFlatStructure()))
        
        return values

    def has_service(self, node, node_id, services_filter):
        services = self.get_services(node_id)

        for filter in services_filter:
            for service in services:
                if filter == service['value']:
                    return True
            
        return False
    
    def get_services(self, node_id=None):
        values = []

        if not self.nodes:
            self.nodes = java.XDaemon.getDaemons()
        
        for node in self.nodes:
            try:
                if node_id:
                    md5 = hashlib.md5()
                    md5.update(node.getAdd() + str(node.getPort()))
    
                    if node_id == md5.hexdigest():
                        values = []
                        self.__build_services(node, values) 
                        break
                else: 
                    self.__build_services(node, values)
            except:
                continue

        return values

    def start_service(self, node, service, threads=1):
        return bool(java.XDaemon.startService(
            service,
            jpype.java.lang.Integer(threads),
            java.certificate, 
            java.SingleCommAddress.parse(node)
        ))
    
    def stop_service(self, node, service):
        return bool(java.XDaemon.stopService(
            service,
            java.certificate, 
            java.SingleCommAddress.parse(node)
        ))

    def restart_service(self,node, service):
        return bool(java.XDaemon.restartService(
            service,
            java.certificate, 
            java.SingleCommAddress.parse(node)
        ))

    def __build_services(self, node, values):
        services = java.XDaemon.getServiceList(node)

        for service in services:
            if not self.__service_exist(service, values):
                values.append({
                    'text': service, 
                    'value': service
                })
                
    def __service_exist(self, service, values):
        for value in values:
            if value['value'] == service:
                return True
            
class NodeLocation(models.Model):
    node = models.CharField(max_length=255)
    lat = models.DecimalField(max_digits=18, decimal_places=10, null=True)
    lng = models.DecimalField(max_digits=18, decimal_places=10, null=True)
    
    def __unicode__(self):
        return self.node
