from common.utils import JsonHttpResponse
from common.views import login_required

from dixi.models import NodesManager, NodeLocation

manager = NodesManager()

@login_required
def nodes(request):
    services = request.REQUEST.get('services', None)
    data = { 'success': False }
    
    if services:
        services = services.split(',')

    try:
        nodes = manager.get_nodes(services)
        data = { 
            'success' : True,
            'data': nodes
        }
    except:
        pass
    
    return JsonHttpResponse(data)

@login_required
def services(request):
    return JsonHttpResponse({ 
        'success' : True,
        'data': manager.get_services(request.REQUEST.get('node_id', None))
    })

@login_required
def services_combo(request):
    return JsonHttpResponse(manager.get_services())

@login_required
def services_info(request):
    node = request.REQUEST.get('node', None)
    data = { 'success': False }

    if node:
        data['data'] = manager.get_node(node)
        data['success'] = True

    return JsonHttpResponse(data)

@login_required
def services_start(request):
    node = request.REQUEST.get('node', None)
    threads = request.REQUEST.get('threads', 0)
    services = request.REQUEST.get('services', None)
    data = { 'success': False }
    
    if services:
        services = services.split(',')
    
        for service in services:
            data['success'] = manager.start_service(node, service, threads)

    return JsonHttpResponse(data)

@login_required
def services_stop(request):
    node = request.REQUEST.get('node', None)
    services = request.REQUEST.get('services', None)
    data = { 'success': False }
    
    if services:
        services = services.split(',')
    
        for service in services:
            data['success'] = manager.start_service(node, service)

    return JsonHttpResponse(data)

@login_required
def services_restart(request):
    node = request.REQUEST.get('node', None)
    services = request.REQUEST.get('services', None)
    data = { 'success': False }
    
    if services:
        services = services.split(',')
    
        for service in services:
            data['success'] = manager.restart_service(node, service)
    
    return JsonHttpResponse(data)

@login_required
def nodes_location(request):
    node = request.REQUEST.get('node', None)
    data = { 'success': False }
    
    if node:
        values = NodeLocation.objects.filter(node=node).values('lat', 'lng')
        values = values[0] if values else None

        if values:
            values['lat'] = '%s' % values['lat']
            values['lng'] = '%s' % values['lng']
            
            data['success'] = True
            data['data'] = values
    
    return JsonHttpResponse(data)

@login_required
def nodes_location_save(request):
    lat = request.REQUEST.get('lat', None)
    lng = request.REQUEST.get('lng', None)
    node = request.REQUEST.get('node', None)
    data = { 'success': True }
    
    try:
        if node and lat and lng:
            location = NodeLocation.objects.filter(node=node)            
            location = NodeLocation() if not location else location[0]
            location.lat = str(lat)
            location.lng = str(lng)
            location.node = node
            location.save()
    except:
        data = { 'success': False }
            
    return JsonHttpResponse(data)
