from django.shortcuts import render_to_response
from django.template import RequestContext

from common.utils import JsonHttpResponse
from common.views import login_required
from monitoring.models import MonitoringSession, geoip

@login_required
def notifications_json(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    
    result = {
        'success': True,
        'data': []
    }
    
    try:
        notifications = monitoring_session.pop_notifications()
        
        for notification in notifications:
            result['data'].append(notification.serialize())
    except:
        import traceback
        traceback.print_exc()
        
    
    return JsonHttpResponse(result)

@login_required
def subscriptions_json(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    
    print monitoring_session
    
    result = {
        'success': True,
        'data': []
    }
    
    for subscription in monitoring_session.subscriptions():
        result['data'].append(subscription.serialize())
    
    return JsonHttpResponse(result)

@login_required
def subscriptions_unsubscribe(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    
    if request.method == 'POST' and 'id' in request.POST:
        id = request.POST['id'].strip()
        
        subscriptions = monitoring_session.subscriptions().filter(id=id)
        if subscriptions:
            monitoring_manager = monitoring_session.get_manager()
            monitoring_manager.monitoring_unsubscribe(id)
            subscriptions.delete()
    
    return JsonHttpResponse({})

@login_required
def rules_json(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    monitoring_manager = monitoring_session.get_manager()
    
    result = {
        'success': True,
        'data': monitoring_manager.monitoring_rules()
    }
    
    return JsonHttpResponse(result)

@login_required
def rules_create(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    monitoring_manager = monitoring_session.get_manager()
    
    result = {
        'success': False,
        'errors': 'Creating rule failed.'
    }
    
    if request.method == 'POST' and 'handle' in request.POST:
        fields = ['handle', 'vo', 'user', 'usergroup', 'job', 'resource', 'aggregation_method',
                                    'aggregation_params', 'comparator', 'condition']
        
        kwargs = dict([(x, request.POST.get(x, None)) for x in fields])
        
        ap = kwargs['aggregation_params']
        if ap:
            kwargs['aggregation_params'] = ap.replace(', ', ',').split(',')
        
        try:
            rule = monitoring_manager.generate_rule(**kwargs)
            
            if request.POST.get('subscribe', False) == 'on':
                monitoring_manager.monitoring_subscribe(rule)
            
            result = {
                'success': True,
                'rule': rule
            }                
        except:
            import traceback
            traceback.print_exc()
            
    return JsonHttpResponse(result)

@login_required
def rules_subscribe(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    
    result = {
        'success': False,
        'errors': 'Subscribing to rule failed.'
    }
    
    if request.method == 'POST' and 'rule' in request.POST:
        rule = request.POST['rule'].strip()
        
        if not monitoring_session.subscriptions().filter(rule=rule):
            monitoring_manager = monitoring_session.get_manager()
            id = monitoring_manager.monitoring_subscribe(rule)
            
            if id:
                result = {'success': True}
        else:
            result['errors'] = 'You are already subscribed to this rule.'
    
    return JsonHttpResponse(result)

@login_required
def rules_unsubscribe(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    
    if request.method == 'POST' and 'rule' in request.POST:
        rule = request.POST['rule'].strip()
        
        subscriptions = monitoring_session.subscriptions().filter(rule=rule)
        if subscriptions:
            monitoring_manager = monitoring_session.get_manager()
            monitoring_manager.monitoring_unsubscribe(subscriptions[0].id)
            subscriptions.delete()
    
    return JsonHttpResponse({})


@login_required
def resources_json(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    monitoring_manager = monitoring_session.get_manager()
    
    result = {
        'success': True,
        'data': monitoring_manager.get_resources()
    }
    
    return JsonHttpResponse(result)

@login_required
def vos_json(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    monitoring_manager = monitoring_session.get_manager()
    
    result = {
        'success': True,
        'data': monitoring_manager.get_vos()
    }
    
    return JsonHttpResponse(result)

@login_required
def users_json(request):
    monitoring_session = MonitoringSession.objects.get_monitoring_session(request)
    monitoring_manager = monitoring_session.get_manager()

    monitoring_manager.get_users()
    
    result = {
        'success': True,
        'data': monitoring_manager.get_users()
    }
    
    return JsonHttpResponse(result)
