from django.conf import settings
from common.java import JavaInterface, Callback, logging

from xml.dom.minidom import parseString
import jpype
import os

java = JavaInterface()

class PolicyConstants(object):
    config = {
        'SubjectConstants': java.XACMLConstants.SubjectConstants.values(),
        'ResourceConstants': java.XACMLConstants.ResourceConstants.values(),
        'ResourceJSDLConstants': java.XACMLConstants.ResourceJSDLConstants.values(),
        'ActionConstants': (java.XACMLConstants.ActionConstants.values(), 'http://www.w3.org/2001/XMLSchema#string'), 
        'MonitoringConstants': (java.XACMLConstants.MonitoringConstants.values(), 'http://www.w3.org/2001/XMLSchema#double'),
    }

    def export(self, key=None):
        values = None
        
        if key:
            values = []
            for conf in self.config.keys():
                if conf.startswith(key):
                    values += self.__buildExport(self.config[conf])
        else:
            values = {}
            for key, value in self.config.items():
                values[key] = self.__buildExport(value)

        return values
    
    def __buildExport(self, value):
        values = []
        members = value
        
        if isinstance(value, tuple):
            members = value[0]

        for m in members:
            values.append({
               'name': m.getAttributeName(), 
               'value': '%s|%s' % (m.getAttributeName(), value[1] if isinstance(value, tuple) else m.getDataType())   
            })
            
        return values        

class PolicyManager(object):
    user_guid = None
    
    def __init__(self):
        self.user_guid = java.certificate.getSubjectDN().getName()
        self.user_guid = self.user_guid.split('=')[1]

    def list(self):
        policies = java.XVOPS.listPolicies(
            self.user_guid, 
            java.VOPSConfig.USER_STR, 
            java.certificate
        )
        
        result = ''
        
        for policy in policies:
            result += java.XVOPS.listPolicy(
               policy.split('"')[1], 
               self.user_guid,
               java.VOPSConfig.USER_STR, 
               java.certificate
           )
            
        return '<Policies>%s</Policies>' % result
    
    def save(self, value):
        try:
            dom = parseString(value)
            policies = dom.getElementsByTagName('Policy')
             
            for policy in policies:
                java.XVOPS.removePolicy(
                    policy.attributes['PolicyId'].value,
                    self.user_guid, 
                    java.VOPSConfig.USER_STR, 
                    jpype.java.lang.Boolean(False), 
                    java.certificate
                )
                java.XVOPS.addPolicy(
                    policy.toxml(), 
                    None, 
                    self.user_guid, 
                    java.VOPSConfig.USER_STR, 
                    jpype.java.lang.Boolean(False), 
                    java.certificate
                )
        except:
            return False
        return True
    
    def templates(self):
        dir = settings.VOPS_TEMPLATES_DIR
        result = []
    
        for filename in os.listdir(dir):
            if os.path.isfile(os.path.join(dir, filename)):
                f = open('%s/%s' % (dir, filename), 'r')
                result.append({
                    'name': filename.split('.')[0], 
                    'value': f.read()
                })
                
        return result
