import os
from sys import path

PROJECT_DIR = os.path.abspath(os.path.dirname(__file__))

APP_DIRS = (
    'external',
    'local',
)

for app in APP_DIRS:
    path.insert(0, '%s/%s' % (PROJECT_DIR, app))

DEBUG = False
TEMPLATE_DEBUG = DEBUG

ADMINS = (
    ('Luka Zakrajsek', 'luka.zakrajsek@xlab.si'),
)

MANAGERS = ADMINS

DATABASE_ENGINE = 'mysql'    # 'postgresql_psycopg2', 'postgresql', 'mysql', 'sqlite3' or 'ado_mssql'.
DATABASE_NAME = 'webmon'       # Or path to database file if using sqlite3.
DATABASE_USER = 'webmon'             # Not used with sqlite3.
DATABASE_PASSWORD = 'webmon'         # Not used with sqlite3.
DATABASE_HOST = ''             # Set to empty string for localhost. Not used with sqlite3.
DATABASE_PORT = ''             # Set to empty string for default. Not used with sqlite3.

TIME_ZONE = 'Europe/Ljubljana'

SITE_ID = 1

MEDIA_ROOT = os.path.join(PROJECT_DIR, 'static/')
MEDIA_URL = '/static/'
ADMIN_MEDIA_PREFIX = '/static/admin/'

FIXTURE_DIRS = [os.path.join(PROJECT_DIR, 'fixtures')]

SECRET_KEY = 'xsb4384g)d9c5mn5@h9g_a8y9u2o$b1$h+z1gr^cu_%24v=-xk'

TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.load_template_source',
    'django.template.loaders.app_directories.load_template_source',
)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.core.context_processors.i18n',
    'django.core.context_processors.request',
    'django.core.context_processors.media',
)

TEMPLATE_DIRS = (
    os.path.join(PROJECT_DIR, 'templates'),
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.doc.XViewMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
)

INTERNAL_IPS = ('127.0.0.1',)

ROOT_URLCONF = 'urls'

USE_I18N = False

INSTALLED_APPS = (
    # django
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'debug_toolbar',
    'django_extensions',
    # apps
    'common',
    'monitoring',
    'vops',
    'dixi',
)

LOGIN_URL = '/login'
LOGIN_REDIRECT_URL = '/'
LOGOUT_URL = '/'

LOG4J_PROPERTIES = os.path.join(PROJECT_DIR, 'log4j.properties')
HOME_PATH = os.path.expandvars(os.path.expanduser('~'))
CERTIFICATE_PATH = os.path.join(HOME_PATH, '.xos/truststore/certs/user.crt')
JAVA_HOME = '/etc/alternatives/java_sdk_1.6.0/jre/lib/i386/client/libjvm.so'

GEOIP_DB_PATH = '/usr/share/GeoIP/GeoLiteCity.dat'
GEOIP_FALLBACK_DATA = { 
    'latitude': 46.051443,
    'longitude': 14.506074
}

VOPS_TEMPLATES_DIR = PROJECT_DIR + '/local/vops/templates'
DIXI_CACHE_TTL = 60*60

try:
    from local_settings import *
except ImportError:
    pass
