Ext.namespace('App.Auditing');

var handleList = [
	['cpu_system'],
	['cpu_user'],
	['mem_total'],
	['mem_free'],
	['disk_total'],
	['disk_free'],
	['jobs_running'],
	['job_started'],
	['job_finished'],
	['job_failed'],
	['login_failed'],
	['rca_apply'],
	['rca_confirm'],
	['rca_request'],
	['rca_unregisters'],
	['rca_vo_membership_add'],
	['rca_vo_membership_remove']
];

App.Auditing.RulesGrid = Ext.extend(Ext.grid.GridPanel, {
    initComponent: function () {
        Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'auditing-rules-grid'
        	,frame: true
        	,title: 'Rules'
        	,autoScroll: true
        	,loadMask: { msg: "Please wait..." }
        	,store: new Ext.data.JsonStore({
        	    successProperty: 'success'
        		,root: 'data'
        		,idProperty: 'invalid'
        		,autoLoad: true
        		,fields: [
        			{name: 'rule'}
        			,{name: 'query'}
        		]
        		,proxy: new Ext.data.HttpProxy({
        			url: '/auditing/rules'
        		})
        	})
        	,enableHdMenu: false
        	,columns: [
    	  		{header: 'Rule', width: 60, dataIndex: 'rule'}
    	  		,{header: 'Query', width: 120, dataIndex: 'query'}
	  		]
    	  	,tbar: [
	  	        {
        	  		text: 'Refresh'
        	  		,iconCls: 'silk-table-refresh'
        	  		,handler: function(b, e) {
	  	        		App.Auditing.Rules.store.reload();
    	  			}
    	  		}
	  	        ,{
	  	        	text: 'Create'
	  	        	,iconCls: 'silk-add'
	  	        	,handler: function(b, e) {
		  	        	var win = new Ext.Window({
			  	          	id: 'auditing-rules-window'
			  	          	,title: 'Create rule'
			  	          	,fit: true
			  	          	,width: 500
			  	          	,resizable: false
			  	          	,plain: true
			  	          	,border: false
			  	          	,modal: true
			  	          	,buttons: [ 
			  	  	            { 
			  	  	            	text: 'Create'
			  	  	            	,handler: function() {
			  	  	            		App.Auditing.Rules.fireEvent('auditing-rules-add');
			  	  	            	}
			  	          		}
			  	  	            ,{ 
			  	  	            	text: 'Close'
			  	  	            	,handler: function() {
			  	  	            	    Ext.getCmp('auditing-rules-window').close();
			  	  	            	}
			  	          		}
			  	            ]
			  	          	,items: [
			  	  				new Ext.FormPanel({
			  	  					id: 'auditing-rules-window-form'
									,frame: true
									,border: false							
									,labelWidth: 75
									,labelAlign: 'right'
								    ,bodyStyle:'padding:5px'
							    	,defaults: { width: 380 }	
			  	  					,items: [
			  	  					    {
			  	  				    		xtype: 'combo'
			  	  				    		,allowBlank: false
			  	  				    		,fieldLabel: 'Handle'
			  	  					    	,name: 'handle'
			  	  					        ,displayField: 'handle'
			  	  					        ,typeAhead: false
			  	  					        ,mode: 'local'
			  	  					        ,triggerAction: 'all'
			  	  					        ,emptyText: ''
			  	  					        ,editable: false
			  	  					        ,store: new Ext.data.ArrayStore({
			  	  					            fields: ['handle']
			  	  					            ,data: handleList
			  	  					        })
			  	  					    }
			  	  				    ]
			  	  				})
		
			  	  			]
	  	        		});
		  	        	
	  	        		win.show(this);
    	  			}
	  	        }
	  	        ,{
        	  		text: 'Cancel'
        	  		,id: 'auditing-rules-btn.cancel'
        	  		,iconCls: 'silk-cross'
    	  			,disabled: true
        	  		,handler: function(b, e) {
	  	        		App.Auditing.Rules.fireEvent('auditing-rules-cancel');
    	  			}
    	  		}
  	        ]
    	  	,viewConfig: {
    	  		forceFit: true
    	  	}

        }));

        App.Auditing.RulesGrid.superclass.initComponent.apply(this, arguments);
    }
});

App.Auditing.DataGrid = Ext.extend(Ext.grid.GridPanel, {
    initComponent: function () {
        Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'auditing-data-grid'
        	,frame: true
        	,title: 'Data'
        	,autoScroll: true
        	,store: new Ext.data.JsonStore({
        	    successProperty: 'success'
        		,root: 'data'
    			,autoLoad: false
        		,idProperty: 'invalid'
    			,baseParams: {
    				action: 'query'
				}
        		,proxy: new Ext.data.HttpProxy({
        			url: '/auditing/data/query'
        		})
        		,reader: new Ext.data.JsonReader()
        	})
        	,loadMask: { msg: "Please wait..." }
        	,enableHdMenu: false
        	,columns: [{ header: 'value', dataIndex: 'value' }]
    	  	,tbar: [
	  	        {
        	  		text: 'Refresh'
        	  		,iconCls: 'silk-table-refresh'
        	  		,handler: function(b, e) {
	  	        		App.Auditing.Data.store.reload();
    	  			}
    	  		}
	  	        ,{
        	  		text: 'Clear'
        	  		,iconCls: 'silk-grid'
        	  		,handler: function(b, e) {
	  	        		App.Auditing.Data.store.removeAll();
    	  			}
    	  		}
	  	        ,{
	  	        	text: 'Query'
	  	        	,iconCls: 'silk-add'
	  	        	,handler: function(b, e) {
		  	            var win = new Ext.Window({
		  	            	id: 'auditing-data-window'
		  	        		,title: 'Query database'
		  					,frame: true
		  					,modal: true
		  					,border: false	
		  	                ,width: 580
		  	                ,items: [
		  						new Ext.FormPanel({
		  							id: 'auditing-data-window-form'
		  							,frame: true
		  							,border: false							
		  							,labelWidth: 75
		  							,labelAlign: 'right'
		  						    ,bodyStyle:'padding:5px'
		  					    	,defaults: { width: 460 }
		  						    ,items: [
		  								new Ext.form.TextArea({
		  									fieldLabel: 'SQL'
		  								    ,name: 'sql'
		  								    ,height: 220
		  								    ,allowBlank: false
		  								})
		  						    ]
		  						})
		  	                ]
		  	                ,buttons: [
		  	                    {
		  	                    	text: 'Execute'
		  	            			,handler: function() {
		  	                    		App.Auditing.Data.fireEvent('auditing-query-execute');
		  	                		}
		  	                	}
		  	                    ,{
		  	                    	text: 'Close'
		  	            			,handler: function() {
		  	                    		Ext.getCmp('auditing-data-window').close();
		  	                		}
		  	                	}
		  	            	]
		  	            });
		  	            
		  	            win.show(this);
	  	        	}
	  	        }
  	        ]
    	  	,viewConfig: {
    	  		forceFit: true
    	  	}

        }));

        App.Auditing.DataGrid.superclass.initComponent.apply(this, arguments);
    }
});