Ext.onReady(function() {
	App.Auditing.Rules = new App.Auditing.RulesGrid();
	App.Auditing.Data = new App.Auditing.DataGrid();
	
	// add auditing rule
	App.Auditing.Rules.on('auditing-rules-add', function() {
		var window = Ext.getCmp('auditing-rules-window');
		var form = window.items.get(0).getForm();
		
		if (form.isValid()) {
			var handle = form.getValues().handle;
			
			Ext.Ajax.request({
				url: '/auditing/rules/add'
				,params: { handle: handle }
				,success: function(data) {
					var data = Ext.util.JSON.decode(data.responseText);
					window.close();
					
					if (data.success) {
						App.showMessage(String.format('Added new rule with handle "{0}".', handle));
						App.Auditing.Rules.store.reload();
					}
				}
				,failure: function() {
					window.close();
				}
			});
		}
	});
	
	// control cancel button
	App.Auditing.Rules.on('rowclick', function(grid, rowIndex) {
		var nodes = grid.getSelectionModel().getSelections();
	    var remove = Ext.getCmp('auditing-rules-btn.cancel');

		if (nodes.length) {
			remove.enable();
		}
		else {
			remove.disable();
		}
	});
	
	// cancel auditing rule
	App.Auditing.Rules.on('auditing-rules-cancel', function() {
		var rules = App.Auditing.Rules.getSelectionModel().getSelections();
		
		if (rules && rules.length) {
			var data = new Array();
			
			for (rule in rules) {
				var value = rules[rule].data;
				if (value) data.push(value.rule);
			}
			
			Ext.Ajax.request({
				url: '/auditing/rules/cancel'
				,params: { rules: data.toString() }
				,success: function(data) { 
					var data = Ext.util.JSON.decode(data.responseText);
					
					if (data.success) {
						App.showMessage('Selected rules cancelled.');
						Ext.getCmp('auditing-rules-btn.cancel').disable();
						App.Auditing.Rules.getSelectionModel().clearSelections(true);
						App.Auditing.Rules.store.reload();
					}
				}
			})
		}
	});
	
	// executes passed query
	App.Auditing.Data.on('auditing-query-execute', function() {
		var form = Ext.getCmp('auditing-data-window-form').items.get(0);
		var sql = form.getValue();
		
		if (sql) {
			sql = sql.trim();
			sql = sql.replace(/[\n\r\t]/g, ' ');
		}

		if (form.isValid()) {
			App.Auditing.Data.store.baseParams = { action: 'filter', sql: sql };
			App.Auditing.Data.store.load();
			
			Ext.getCmp('auditing-data-window').close()
		}
	});
	
	// dynamicly add columns to grid
	App.Auditing.Data.store.on('metachange', function(store, meta) {
		var grid = App.Auditing.Data;
		var columns = [] 
		 
		for (var i = 0; i < meta.fields.length; i++ ) {
			columns.push({
				header: meta.fields[i].header
				,dataIndex: meta.fields[i].mapping
				,type: meta.fields[i].type
			});
        }

        grid.reconfigure(App.Auditing.Data.store, new Ext.grid.ColumnModel(columns));
	});
});
