Ext.namespace('App.Dixi');

App.Dixi.ServicesStore = new Ext.data.JsonStore({
    autoLoad: true
    ,proxy: new Ext.data.HttpProxy({ url: '/dixi/services/list/combo' })
    ,fields: ['value','text']
    ,sortInfo: {
    	field: 'value'
        ,direction: 'ASC'
    }
});

App.Dixi.NodesGrid = Ext.extend(Ext.grid.GridPanel, {
    initComponent: function () {
    	Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'dixi-nodes-grid'
    		,frame: false
    		,autoScroll: true
            ,defaults: { sortable: false }
    		,loadMask: { msg: "Please wait..." }
    		,store: new Ext.data.JsonStore({
    			successProperty: 'success'
    			,root: 'data'
    			,autoLoad: true
    			,fields: [
		         	{name: 'address'}
    			    ,{name: 'host'}
    				,{name: 'port'}
    			]
    			,baseParams: {
    				action: 'filter'
				}
    			,proxy: new Ext.data.HttpProxy({
    				url: '/dixi/nodes/list'
    			})
    		})
    		,columns: [
	          	{header: 'Address', dataIndex: 'address'}
    			,{header: 'Host', dataIndex: 'host'}
    			,{header: 'Port', dataIndex: 'port'}
    		]
    		,tbar: [
		        {
		        	text: 'Refresh'
	        		,iconCls: 'silk-table-refresh'
        			,handler: function() {
		        		App.Dixi.Nodes.getGrid().store.reload();
		        		App.showMessage('Nodes list refreshed.');
    				}
		        }
		        ,{
		        	text: 'Info'
	        		,iconCls: 'nodes-info'
        			,disabled: true
        			,handler: function() {
		        		App.Dixi.Nodes.fireEvent('nodes-info');
    				}
		        }
		        ,{
		        	text: 'Location'
	        		,iconCls: 'nodes-location'
        			,disabled: true
        			,handler: function() {
		        		App.Dixi.Nodes.fireEvent('nodes-location');
    				}
		        }
		        ,{
		        	text: 'Filter'
	        		,iconCls: 'silk-grid'
        			,handler: function() {
			        	var win = new Ext.Window({
	                    	id: 'dixi-nodes-filter-window'
	                		,title: 'Filter'
							,modal: true
	                        ,width: 696
	                        ,items: [
								new Ext.FormPanel({
									id: 'dixi-nodes-filter-window-form'
									,frame: false
									,border: false
									,width: 690
								    ,bodyStyle: 'padding:10px'
								    ,items: [
										{
										    xtype: 'itemselector'
										    ,name: 'services'
										    ,hideLabel: true
										    ,imagePath: '/static/ext/ux/images/'
										    ,drawUpIcon: false
										    ,drawDownIcon: false
										    ,drawTopIcon: false
										    ,drawBotIcon: false
										    ,multiselects: [{
										        width: 320
										        ,height: 200
										        ,store: App.Dixi.ServicesStore
								                ,displayField: 'text'
								                ,valueField: 'value'
										    }
										    ,{
										    	width: 320
										        ,height: 200
										        ,store: 
										        	(App.Dixi.Nodes.getGrid().store.baseParams.services) ? 
									        		    App.Dixi.Nodes.getGrid().store.baseParams.services.split(',') : []
								                ,tbar: [{
								                    text: 'clear'
								                    ,handler:function() {
								                		Ext.getCmp('dixi-nodes-filter-window').items.get(0)
								                			.getForm().findField('services').reset();
								                	}
								                }]
										    }]
										}
								    ]
								})
	                        ]
	                        ,buttons: [
	                        	{
	                        		text: 'Apply'
	                    			,handler: function() {
	                        			App.Dixi.Nodes.fireEvent('nodes-filter-add');
	                        		}
	                        	}
	                        	,{
	                        		text: 'Close'
	                    			,handler: function() {
	                        			Ext.getCmp('dixi-nodes-filter-window').close();
	                        		}
	                        	}
	                    	]
	                    });
	                    
	                    win.show(this);
    				}
		        }
	        ]
    		,viewConfig: {
    			forceFit: true
    		}
    	}));
    	
    	App.Dixi.NodesGrid.superclass.initComponent.apply(this, arguments);
    }
});

App.Dixi.ServicesGrid = Ext.extend(Ext.grid.GridPanel, {
    initComponent: function () {
    	Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'dixi-services-grid'
    		,frame: false
    		,autoScroll: true
    		,loadMask: { msg: "Please wait..." }
    		,store: new Ext.data.JsonStore({
    			successProperty: 'success'
    			,root: 'data'
    			,fields: [
		            { name: 'value' }
    			]
    			,baseParams: {
    				action: 'filter'
				}
    			,proxy: new Ext.data.HttpProxy({
    				url: '/dixi/services/list'
    			})
    		})
    		,enableHdMenu: false
    		,columns: [
	          	{header: 'Services', dataIndex: 'value'}
    		]
    		,tbar: [
		        {
		        	text: 'Refresh'
	        		,iconCls: 'silk-table-refresh'
        			,handler: function() {
		        		App.Dixi.Nodes.getActiveTab().items.get(0).store.reload();
		        		App.showMessage('Service list refreshed.');
    				}
		        }
		        ,{
		        	text: 'Start'
	        		,disabled: true
	        		,iconCls: 'nodes-control-start'
        			,handler: function(element) {
		        		App.Dixi.Nodes.fireEvent('nodes-services-start', element.ownerCt.ownerCt);
		        	}
		        }
		        ,{
		        	text: 'Stop'
	        		,disabled: true
	        		,iconCls: 'nodes-control-stop'
        			,handler: function(element) {
		        		App.Dixi.Nodes.fireEvent('nodes-services-stop', element.ownerCt.ownerCt);
		        	}
		        }
		        ,{
		        	text: 'Restart'
		        	,disabled: true
	        		,iconCls: 'nodes-control-restart'
        			,handler: function(element) {
		        		App.Dixi.Nodes.fireEvent('nodes-services-restart', element.ownerCt.ownerCt);
		        	}
		        }
	        ]
    		,viewConfig: {
    			forceFit: true
    		}
    	}));
    	
    	App.Dixi.ServicesGrid.superclass.initComponent.apply(this, arguments);
    }
});

App.Dixi.TabPanel = Ext.extend(Ext.TabPanel, {
    initComponent: function () {
        Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'dixi'
    		,bodyStyle: 'padding:1px;'
            ,activeTab: 0
            ,items: [ 
             	{
             		id: 'nodes'
             		,title: 'Nodes'
         			,layout: 'fit'
             		,items: new App.Dixi.NodesGrid()
             	}
         	]
        }));

        App.Dixi.TabPanel.superclass.initComponent.apply(this, arguments);
    }
    ,getGrid : function() {
    	return this.items.get(0).getComponent('dixi-nodes-grid');
    }
});