var chart_counter = 1; 

Chart = Ext.extend(Ext.Panel, {
	layout: 'fit',
    closable: true,
    autoScroll: true,
    
    initComponent: function(config) {
		this.chart = null;
		this.chartOptions = {
		    width: 600,
		    height: 300,
		    maxXDisplay: 600000,
		    xBoxes: 25,
		    yBoxes: 10,
		    yMin: 0,
		    yMax: 100,
		    xMin: 0,
		    xMax: 600,
		    yPad: 0,
		    yFormat: '%d%%'
		};
	
		this.series = [{
		    showMarker: false,
		    data: [[0, -10]],
		    initialSerie: true
		}];
	
		this.rendered = false;
	
        this.items = [{
            xtype: 'panel',
            ref: 'chartHolder',
            layout: 'absolute',
            width: this.chartOptions.width,
            height: this.chartOptions.height
        }];
        
        if(config == undefined || config.title == undefined){
        	this.title = 'Chart ' + chart_counter++;
        }
        
        Chart.superclass.initComponent.call(this, config);
        
        this.on('render', this.onChartRender, this);
    },
    
    redrawChart: function(){
    	if(this.rendered && $('#' + this.body.id).is(':visible')){
	    	var data = Ext.pluck(this.series, 'data');
	    	
	    	$('#' + this.body.id).empty();
	    	
	    	this.body.setWidth(this.chartOptions.width);
	        this.body.setHeight(this.chartOptions.height);
	        
			Ext.DomHelper.applyStyles(this.body, {
				overflow: 'visible'
			});
	        
	    	this.chart = $.jqplot(this.body.id, data, {
	            title: this.title,
	            seriesColors: ['#00FF00', '#0080FF', '#FF0000', '#0000FF'],
	            
	            series: this.series,
	            
	            axes: {
	                xaxis: {
	                    padMax: 0,
	                    padMin: 0,
	                    min: this.chartOptions.xMin,
	                    max: this.chartOptions.xMax,
	                    numberTicks: this.chartOptions.xBoxes + 1,
	                    showTicks: false,
	                    renderer: $.jqplot.DateAxisRenderer,
	                    tickOptions: { formatString: '%Y/%m/%d %H:%M:%S' }
	                },
	                yaxis: {
	                    tickOptions: { formatString: '&nbsp;<nobr>' + this.chartOptions.yFormat + '</nobr>' },
	                    min: this.chartOptions.yMin,
	                    max: this.chartOptions.yMax,
	                    numberTicks: this.chartOptions.yBoxes + 1,
	                    yPad: this.chartOptions.yPad
	                }
	            },
	            
	            grid: {
	                gridLineColor: '#008000',
	                background: '#000000'
	            },
	            cursor: {
	            	zoom: true,
	            	useAxesFormatters: true
	        	},
	            highlighter: {
	        		show: true,
	        		sizeAdjust: 10,
	        		tooltipLocation: 'ne'
	    		}
	        });
    	}
    },
    
    addSerie: function(store, filter_record){
    	if(this.series[0].initialSerie){
    		this.series.shift();
    		
    		var unit = filter_record.data.value_unit;
        	
        	if(unit == 'PERCENT'){
        		this.chartOptions.yMin = 0;
        		this.chartOptions.yMax = 100,
        		this.chartOptions.yPad = 0,
        		this.chartOptions.yFormat = '%d%%'
        	}else{
        		this.chartOptions.yMin = undefined;
        		this.chartOptions.yMax = undefined;
        		this.chartOptions.yPad = 1.1;
        		this.chartOptions.yFormat = '%d ' + unit;
        		
        		if(unit == 'TB' || unit == 'GB' || unit == 'MB' || unit == 'KB' || unit == 'B'){
        			this.chartOptions.yFormat = '%.1f ' + unit;
        		}
        	}
    	}
    	
    	this.series.push({
            neighborThreshold: 0,
            shadow: true,
            lineWidth: 1.5,
            showMarker: false,
            data: [],
        });
    	
    	var filter = function(record){
    		if(record.data.query == filter_record.data.query){
    			return true;
    		}
    		
    		return false;
    	}
    	
    	var serie = this.series[this.series.length - 1];
    	var chart = this;
    	
    	var records = [];
    	Ext.each(store.getRange(), function(record){
    		if(filter(record)){
    			records.push(record);
    		}
    	});
    	
    	Ext.each(records, function(record, i){
    		chart.addToGraphSerie(serie, record.data.timestamp.getTime(), record.data.value_original); 
    	});
    	
    	store.on('load', function(s, rs, o){
    		var records = [];
        	Ext.each(rs, function(record){
        		if(filter(record)){
        			records.push(record);
        		}
        	});
    		
    		if(records.length > 0){
    			Ext.each(records, function(record, i){
    				chart.addToGraphSerie(serie, record.data.timestamp.getTime(), record.data.value_original, false); 
    	    	});
    			
    			this.chartRecalculate();
    			this.redrawChart();
    		}
    	}, this);
    	
    	this.redrawChart();
    	
    	return serie;
    },
    
    addToGraphSerie: function(serie, x, y, recalculate){
    	serie.data.push([x, y]);
    	
    	if(recalculate == undefined || recalculate == true){
    		this.chartRecalculate();
    	}
    },
    
    chartRecalculate: function(){
		var xs = [];
    	
    	Ext.each(this.series, function(serie){
    		Ext.each(serie.data, function(el){
    			xs.push(el[0]);
    		});
    	});
    	
    	var min = Ext.min(xs);
    	var max = Ext.max(xs);
    	
    	if(max - min < this.chartOptions.maxXDisplay){
    		this.chartOptions.xMin = min;
    		this.chartOptions.xMax = min + this.chartOptions.maxXDisplay;
    	}else{
    		this.chartOptions.xMin = max - this.chartOptions.maxXDisplay;
        	this.chartOptions.xMax = max;
    	}
    },
    
    onChartHolderRender: function(ct, pos){
        this.rendered = true;
        
        this.redrawChart();
				
		Ext.getCmp('grouptabpanel-dashboard').on('tabchange', function(p, i){
			if(i.id == 'grouptabpanel-charts'){
				this.redrawChart();
			}
		}, this);
		
		this.on('show', function(){
			this.redrawChart();
		}, this);
    },
    
    onChartRender: function(ct, pos){
    	this.chartHolder.on('render', this.onChartHolderRender, this);    	
    	
    	var strip = Ext.get(ct.tabEl);
    	strip.on('dblclick', function(e){
    		if(e.getTarget('.x-tab-strip-text', strip) != null){
    			this.onRename.call(this);
    		}
    	}, this);
    },
    
    onRename: function(){
    	Ext.Msg.prompt('Rename chart', 'Enter new chart name...', function(btn, txt){
    		if(btn == 'ok'){
    			this.setTitle(txt);
    			this.chart.title.text = txt;
    			this.chart.redraw();
    			
    		}
    	}, this, false, this.title);
    }
});

var charts = new Ext.Panel({
    layout: 'fit',
    id: 'charts-panel',
    tbar: [{
    	text: 'New chart',
		iconCls: 'silk-add',
		handler: function(b, e) {
    		charts.addNewChart();
    	},
    	scope: this
    }],
    items: [{
        xtype: 'tabpanel',
        activeTab: 0,
        id: 'charts-tabs',
        ref: 'charts_tabs',
        resizeTabs: true,
        minTabWidth: 115,
        tabWidth: 135,
        enableTabScroll: true,
        defaults: { autoScroll: true },
        items: [
            new Chart()
        ]
    }],
    
    addNewChart: function(){
		var chart = new Chart();
		charts.charts_tabs.add(chart);
		charts.charts_tabs.setActiveTab(charts.charts_tabs.items.length - 1);
		
		return chart;
	}
});