var notificationInfoTemplate = new Ext.Template([
    '<br />&nbsp;&nbsp;&nbsp;- {name}: {value} at {timestamp}</li>'
], {
	compile: true
});

var resourceInfoTemplate = new Ext.Template([
    '<div class="gmaps-popup">',
	    '<p><strong>{resource}</strong></p>',
	    '<p>Last notifications:{notifications}</p>',
    '</div>'
], {
	compile: true
});

var map = new Ext.ux.GMapPanel({
	layout: 'fit',
	deferredRender: false,
    id: 'map-panel',
    
    zoomLevel: 2,
    gmapType: 'map',
    mapConfOpts: ['enableScrollWheelZoom','enableDoubleClickZoom','enableDragging'],
    mapControls: ['GSmallMapControl','GMapTypeControl','NonExistantControl'],
    setCenter: {
		lat: 10,
	    lng: 0
    },
    
    resources: {},
    
    addNotification: function(record){
    	resource = record.data.resource;
    	latitude = record.data.latitude;
    	longitude = record.data.longitude;
    	
    	if(resource && latitude && longitude){
	    	if(resource.indexOf(':') != -1){
	    		resource = resource.substring(0, resource.indexOf(':'));
	    	}
	    	
	    	var myResource = this.resources[resource];
	    	
	    	if(myResource == undefined){
	    		myResource = {
					marker: new google.maps.Marker({
				    		position: new google.maps.LatLng(latitude, longitude),
				    		map: this.getMap(),
				    		title: resource
						}),
					infoWindow: new google.maps.InfoWindow(),
					notifications: [],
					shown: false
	    		};
	    		
	    		this.resources[resource] = myResource;
	    	}
	    	
	    	if(myResource.notifications.length > 2){
	    		myResource.notifications.shift();
	    	}
	    	
	    	myResource.notifications.push(notificationInfoTemplate.apply({
				name: record.data.name,
				value: record.data.value,
				timestamp: record.data.timestamp.format("Y/m/d H:i:s")
			}));
	    	
	    	myResource.infoWindow.setContent(resourceInfoTemplate.apply({
				resource: resource,
				notifications: myResource.notifications.join('')
			}));
	    	
	    	google.maps.event.addListener(myResource.marker, 'click', function() {
    			myResource.infoWindow.open(this.getMap(), myResource.marker);
    		});
	    	
	    	if(!myResource.shown && this.getMap()){
	    		myResource.infoWindow.open(this.getMap(), myResource.marker);
	    		myResource.shown = true;
	    	}
    	}
    },
    
    listeners: {
    	mapready: function(map){
	    	Ext.iterate(this.resources, function(key, resource){
	    		resource.shown = true;
	    		resource.marker.setMap(map.getMap());
	    		resource.infoWindow.open(map.getMap(), resource.marker);
	    	});
	    },
	    scope: map
    }
});

notificationStore.on('load', function(s, rs, o){
	Ext.each(rs, function(record, index){
		map.addNotification(record);
	});
}, map);