var notificationStore = new Ext.data.JsonStore({
	successProperty: 'success',
	root: 'data',
	idProperty: 'invalid',
	autoLoad: true,
	fields: [
		{name: 'id'},
		{name: 'notification_type'},
		{name: 'name'},
		{name: 'value'},
		{name: 'value_original'},
		{name: 'value_unit'},
        {name: 'vo'},
        {name: 'user'},
        {name: 'user_group'},
        {name: 'job'},
        {name: 'resource'},
		{name: 'timestamp', type: 'date'},
		{name: 'subscription'},
		{name: 'query'},
		{name: 'latitude'},
		{name: 'longitude'}
	],
	proxy: new Ext.data.HttpProxy({
		url: '/monitoring/notifications.json'
	}),
	sortInfo: {
		field: 'timestamp',
		direction: 'DESC'
	},
	listeners: {
		load: function(s, rs, o){
			s.sort(s.sortInfo.field, s.sortInfo.direction);
		}
	},
	refresh: function(){
		notificationGrid.store.load({
			add: true
		});
	},
});

var notificationMenu = new Ext.menu.Menu({
	items: [],
	
	addToChart: function(item){
		var s = this.grid.selModel.getSelected();
		if(s != null){
			item.chart.addSerie(this.grid.store, s);
			
			waitDuration('Notifications with query ' + s.data.query + ' added to chart ' + item.chart.title);
		}
	},
	
	addChartToMenu: function(chart){
		var item = notificationMenu.add({
			text: chart.title,
	        handler: function(i){
				notificationMenu.addToChart(i);
			},
	        scope: notificationMenu,
	        chart: chart
		});
		
		notificationMenu.doLayout();
		
		chart.on('titlechange', function(p, txt){
			item.setText(txt);
		});
	}
});

var cts = Ext.getCmp('charts-tabs');

for(var i = 0; i < cts.items.length; i++){
	var chart = cts.items.get(i);
	notificationMenu.addChartToMenu(chart);
}

cts.on('add', function(con, com, i){
	notificationMenu.addChartToMenu(com);
}, cts);

cts.on('remove', function(con, com){
	for(var i = 0; i < notificationMenu.items.length; i++){
		var cmp = notificationMenu.get(i);
		if(cmp.chart == com){
			notificationMenu.remove(cmp);
			notificationMenu.doLayout();
			break;
		}
	}
}, cts);

var notificationGrid = new Ext.grid.GridPanel({
	frame: true,
	title: 'Notifications',
	autoScroll: true,
	store: notificationStore,
	enableHdMenu: false,
	autoRefresh: true,
	columns: [
		{header: 'Type', width: 25, sortable: true, dataIndex: 'notification_type'},
		{header: 'Name', width: 40, sortable: true, dataIndex: 'name'},
		{header: 'Value', width: 30, sortable: true, dataIndex: 'value'},
		//{header: 'VO', width: 30, sortable: true, dataIndex: 'vo'},
		//{header: 'User', width: 30, sortable: true, dataIndex: 'user'},
		//{header: 'User group', width: 30, sortable: true, dataIndex: 'user_group'},
		//{header: 'Job', width: 30, sortable: true, dataIndex: 'job'},
		{header: 'Resource', width: 40, sortable: true, dataIndex: 'resource'},
		{header: 'Timestamp', width: 40, sortable: true, dataIndex: 'timestamp', renderer: function(date){ return date.format("Y/m/d H:i:s"); }},
		{header: 'Query', width: 80, sortable: true, dataIndex: 'query', renderer: qtipRenderer}
	],
	tbar: [{
		text: 'Refresh',
		iconCls: 'silk-table-refresh',
		handler: function(b, e) {
			notificationGrid.store.refresh();
		}
	}, '-', {
		text: 'Clear',
		iconCls: 'silk-grid',
		handler: function(b, e){
			notificationGrid.store.removeAll();
		}
	}, '-', 'Auto-refresh: ', ' ', {
		xtype: 'checkbox',
		id: 'notifications-auto-refresh',
		style: 'margin-top: 0;',
		listeners: {
			check: function(cb, checked){
				notificationGrid.autoRefresh = checked;
			},
			render: function(cb){
				cb.setValue(notificationGrid.autoRefresh);
			}
		}
	}, '-', {
		text: 'Add to chart',
		iconCls: 'silk-add',
		menu: notificationMenu
	}],
	viewConfig: {
		forceFit: true
	},
	listeners: {
		cellcontextmenu: function(g, ri, ci, e){
			notificationGrid.selModel.clearSelections();
			notificationGrid.selModel.selectRow(ri);
			notificationMenu.showAt(e.getXY());
			e.preventDefault();
		}
	}
});

notificationMenu.grid = notificationGrid;

var notificationStoreReloadInterval = setInterval(function(){
	if(notificationGrid.autoRefresh){
		notificationStore.refresh();
	}
}, 3000);
