var resourceStore = new Ext.data.JsonStore({
	successProperty: 'success',
	root: 'data',
	idProperty: 'invalid',
	autoLoad: true,
	fields: [
	    {name: 'resource'},
		{name: 'ip'},
		{name: 'port'},
		{name: 'unique_id'},
		{name: 'computation_resource'},
		{name: 'operating_system_name'},
		{name: 'processor_architecture'},
		{name: 'ram_size'}
	],
	proxy: new Ext.data.HttpProxy({
		url: '/monitoring/resources.json'
	}),
	sortInfo: {
		field: 'ip',
		direction: 'ASC'
	},
	listeners: {
		load: function(s, rs, o){
			s.sort(s.sortInfo.field, s.sortInfo.direction);
		}
	}
});

var resourceGrid = new Ext.grid.GridPanel({
	frame: false,
	autoScroll: true,
	store: resourceStore,
	enableHdMenu: false,
	columns: [
		{header: 'IP', dataIndex: 'ip'},
		{header: 'Port', dataIndex: 'port'},
		{header: 'Unique ID', dataIndex: 'unique_id'},
		new Ext.ux.grid.CheckColumn({header: 'Is CR', dataIndex: 'computation_resource', tooltip: 'Can be used as Computation Resource'}),
		{header: 'OS', dataIndex: 'operating_system_name'},
		{header: 'CPU architecture', dataIndex: 'processor_architecture'},
		{header: 'RAM size', dataIndex: 'ram_size'}
	],
	tbar: [{
		text: 'Refresh',
		iconCls: 'silk-table-refresh',
		handler: function(b, e) {
			resourceGrid.store.reload();
		}
	}],
	viewConfig: {
		forceFit: true
	}
});

var voStore = new Ext.data.JsonStore({
	successProperty: 'success',
	root: 'data',
	idProperty: 'invalid',
	autoLoad: true,
	fields: [
		{name: 'name'},
		{name: 'gvid'},
		{name: 'description'}
	],
	proxy: new Ext.data.HttpProxy({
		url: '/monitoring/vos.json'
	}),
	sortInfo: {
		field: 'name',
		direction: 'ASC'
	},
	listeners: {
		load: function(s, rs, o){
			s.sort(s.sortInfo.field, s.sortInfo.direction);
		}
	}
});

var voGrid = new Ext.grid.GridPanel({
	frame: false,
	autoScroll: true,
	store: voStore,
	enableHdMenu: false,
	columns: [
		{header: 'Name', dataIndex: 'name'},
		{header: 'GVID', dataIndex: 'gvid'},
		{header: 'Description', dataIndex: 'description'}
	],
	tbar: [{
		text: 'Refresh',
		iconCls: 'silk-table-refresh',
		handler: function(b, e) {
			voGrid.store.reload();
		}
	}],
	viewConfig: {
		forceFit: true
	}
});

var userStore = new Ext.data.JsonStore({
	successProperty: 'success',
	root: 'data',
	idProperty: 'invalid',
	autoLoad: true,
	fields: [
		{name: 'realname'},
		{name: 'guid'},
		{name: 'username'},
		{name: 'status'},
		{name: 'affiliation'},
		{name: 'description'},
	],
	proxy: new Ext.data.HttpProxy({
		url: '/monitoring/users.json'
	}),
	sortInfo: {
		field: 'realname',
		direction: 'ASC'
	},
	listeners: {
		load: function(s, rs, o){
			s.sort(s.sortInfo.field, s.sortInfo.direction);
		}
	}
});

var userGrid = new Ext.grid.GridPanel({
	frame: false,
	autoScroll: true,
	store: userStore,
	enableHdMenu: false,
	columns: [
		{header: 'Real name', dataIndex: 'realname'},
		{header: 'GUID', dataIndex: 'guid'},
		{header: 'Username', dataIndex: 'username'},
		{header: 'Status', dataIndex: 'status'},
		{header: 'Affiliation', dataIndex: 'affiliation'},
		{header: 'Description', dataIndex: 'description'}
	],
	tbar: [{
		text: 'Refresh',
		iconCls: 'silk-table-refresh',
		handler: function(b, e) {
			userGrid.store.reload();
		}
	}],
	viewConfig: {
		forceFit: true
	}
});

var resources = [ {
	xtype: 'tabpanel',
	activeTab: 0,
	items: [ {
		title: 'Resources',
		layout: 'fit',
		items: [ resourceGrid ]
	}, {
		title: 'Virtual Organisations',
		layout: 'fit',
		items: [ voGrid ]
	}, {
		title: 'Users',
		layout: 'fit',
		items: [ userGrid ]
	} ]
} ]
