var handleList = [
    ['cpu_system'],
    ['cpu_user'],
    ['mem_total'],
    ['mem_free'],
    ['disk_total'],
    ['disk_free'],
    ['jobs_running'],
    ['job_started'],
    ['job_finished'],
    ['job_failed'],
    ['login_failed'],
    ['rca_apply'],
    ['rca_confirm'],
    ['rca_request'],
    ['rca_unregisters'],
    ['rca_vo_membership_add'],
    ['rca_vo_membership_remove']
];

var ruleForm = new Ext.FormPanel( {
	id: 'rule-form',
	method: 'POST',
	url: '/monitoring/rules/create',
	frame: true,
	border: false,
	buttonAlign: 'center',
	labelWidth: 70,
	bodyStyle: 'padding: 10px 10px 5px 15px;',
	fit: true,
	items: [ {
		xtype: 'combo',
		id: 'rule-handle',
		fieldLabel: 'Handle',
		name: 'handle',
	    store: new Ext.data.ArrayStore({
	        fields: ['handle'],
	        data: handleList
	    }),
	    displayField: 'handle',
	    typeAhead: false,
	    mode: 'local',
	    forceSelection: false,
	    triggerAction: 'all',
	    emptyText: '',
	    selectOnFocus: true,
	    allowBlank: false,
	    msgTarget: 'side'
	}, {
		xtype: 'compositefield',
		fieldLabel: 'VO',
		items: [{
			xtype: 'combo',
			id: 'rule-vo',
		    store: voStore,
		    displayField: 'name',
		    valueField: 'gvid',
		    hiddenName: 'vo',
		    typeAhead: false,
		    mode: 'local',
		    forceSelection: false,
		    triggerAction: 'all',
		    allowBlank: true
		}, {
			xtype: 'storereloadfield',
			store: voStore
		}]
	}, {
		xtype: 'compositefield',
		fieldLabel: 'User',
		items: [{
			xtype: 'combo',
			id: 'rule-user',
		    store: userStore,
		    displayField: 'username',
		    valueField: 'guid',
		    hiddenName: 'user',
		    typeAhead: false,
		    mode: 'local',
		    forceSelection: false,
		    triggerAction: 'all',
		    allowBlank: true
		}, {
			xtype: 'storereloadfield',
			store: userStore
		}]
	}, {
		xtype: 'textfield',
		fieldLabel: 'Usergroup',
		id: 'rule-usergroup',
		name: 'usergroup',
	    allowBlank: true
	}, {
		xtype: 'textfield',
		fieldLabel: 'Job',
		id: 'rule-job',
		name: 'job',
	    allowBlank: true
	}, {
		xtype: 'compositefield',
		fieldLabel: 'Resource',
		items: [{
			xtype: 'combo',
			id: 'rule-resource',
		    store: resourceStore,
		    displayField: 'resource',
		    valueField: 'resource',
		    hiddenName: 'resource',
		    typeAhead: false,
		    mode: 'local',
		    forceSelection: false,
		    triggerAction: 'all',
		    allowBlank: true
		}, {
			xtype: 'storereloadfield',
			store: resourceStore
		}]
	}, {
		xtype: 'fieldset',
		title: 'Conditions',
		collapsible: false,
		labelWidth: 100,
		items: [{
			xtype: 'compositefield',
			fieldLabel: 'Value must be',
			items: [{
				xtype: 'comboempty',
				id: 'rule-condition-comparator',
				name: 'comparator',
			    store: new Ext.data.ArrayStore({
			        fields: ['comparator'],
			        data: [
			            [''],
			        	['>'],
			        	['<'],
			        	['>='],
			        	['<='],
			        	['=='],
			        	['!=']
			        ]
			    }),
			    width: 50,
			    displayField: 'comparator',
			    mode: 'local',
			    triggerAction: 'all',
			    allowBlank: true,
			}, {
				xtype: 'displayfield',
				value: '&nbsp;'
			}, {
				xtype: 'textfield',
				id: 'rule-condition',
				name: 'condition',
			    allowBlank: true
			}]
		}]
	}, {
		xtype: 'fieldset',
		title: 'Aggregation',
		collapsible: false,
		labelWidth: 100,
		items: [{
			xtype: 'compositefield',
			fieldLabel: 'Aggregation method',
			items: [{
				xtype: 'comboempty',
				id: 'rule-aggregation-method',
				name: 'aggregation_method',
			    store: new Ext.data.ArrayStore({
			        fields: ['method'],
			        data: [
			            [''],
			        	['AVG']
			        ]
			    }),
			    width: 50,
			    displayField: 'method',
			    mode: 'local',
			    triggerAction: 'all',
			    allowBlank: true,
			}, {
				xtype: 'displayfield',
				value: '&nbsp;'
			}, {
				xtype: 'textfield',
				id: 'rule-aggregation-params',
				name: 'aggregation_params',
			    allowBlank: true
			}]
		}]
	}, {
		xtype: 'checkbox',
        fieldLabel: 'Subscribe',
        id: 'rule-subscribe',
        name: 'subscribe',
        checked: true
    }],
	buttons: [ {
		text: 'Create rule',
		formBind: true,
		handler: function() {
			ruleForm.getForm().createRule();
		}
	} ],
	keys: [ {
		key: [ Ext.EventObject.ENTER ],
		handler: function() {
			ruleForm.getForm().createRule();
		}
	} ],
	createRule: function() {
		this.on( {
			beforeaction: function() {
				Ext.getCmp('rule-window-statusbar').showBusy();
			}
		});
		
		this.submit( {
			success: function(f, a) {
				Ext.getCmp('rule-window-statusbar').setStatus( {
					text: 'Ready!',
					iconCls: 'x-status-valid'
				});
				
//				if(Ext.getCmp('rule-subscribe').checked)
//					subscriptionGrid.store.reload();
				
				ruleForm.getForm().reset();
				ruleWindow.hide();
				ruleStore.reload();
			},
			failure: function(f, a) {
				var msg;
				
				if (a.failureType == 'server') {
					msg = a.result.errors;
				} else {
					if (typeof (a.response) == 'undefined') {
						msg = 'Field cannot be empty!'
					} else {
						msg = 'Cannot connect to server!';
					}
				}
				
				Ext.getCmp('rule-window-statusbar').setStatus( {
					text: msg,
					iconCls: 'x-status-error'
				});
			}
		});
	}
});

var ruleWindow = new Ext.Window({
	title: 'Create rule',
	id: 'rule-window',
	items: [ ruleForm ],
	fit: true,
	width: 500,
	resizable: false,
	plain: true,
	border: false,
	modal: true,
	closeAction: 'hide',
	defaultButton: 'rule-handle',
	bbar: new Ext.ux.StatusBar({
		text: 'Ready',
		id: 'rule-window-statusbar',
		iconCls: 'x-status-valid'
	})
});

var ruleSubscribe = function(s) {
	new Ext.data.Connection().request({
	    url: '/monitoring/rules/subscribe',
	    method: 'POST',
	    params: {'rule': s.data.rule},
	    success: function(responseObject) {
	    	ruleGrid.store.reload();
//	    	subscriptionGrid.store.reload();
	    },
	    failure: function() {
	        Ext.Msg.alert('Status', 'Subscription failed.');
	    }
	});
}

var ruleUnsubscribe = function(s) {
	Ext.MessageBox.confirm('Unsubscribe', 'Do you really want to unsubscribe from this rule?', function(btn){
		if(btn == 'yes'){
			new Ext.data.Connection().request({
			    url: '/monitoring/rules/unsubscribe',
			    method: 'POST',
			    params: {'rule': s.data.rule},
			    success: function(responseObject) {
			    	ruleGrid.store.reload();
//			    	subscriptionGrid.store.reload();
			    },
			    failure: function() {
			        Ext.Msg.alert('Status', 'Unsubscription failed.');
			    }
			});
		}
	});	
}

var ruleStore = new Ext.data.JsonStore({
	successProperty: 'success',
	root: 'data',
	idProperty: 'invalid',
	autoLoad: true,
	fields: [
	    {name: 'subscribed'},
		{name: 'rule'},
		{name: 'query'},
	],
	proxy: new Ext.data.HttpProxy({
		url: '/monitoring/rules.json'
	}),
	sortInfo: {
		field: 'rule',
		direction: 'ASC'
	},
	listeners: {
		load: function(s, rs, o){
			s.sort(s.sortInfo.field, s.sortInfo.direction);
		}
	}
});

var ruleMenu = new Ext.menu.Menu({
	items: [{
		text: 'Subscribe',
		iconCls: 'silk-pencil',
        handler: function(i){
			var s = ruleGrid.getSelectionModel().getSelected();
		    if(s != null)
		    {
		    	ruleSubscribe(s);
		    }
		}
	},{
		text: 'Unsubscribe',
		iconCls: 'silk-cross',
		handler: function(b, e) {
			var s = ruleGrid.getSelectionModel().getSelected();
		    if(s != null)
		    {
		    	ruleUnsubscribe(s);
		    }
		}
	}]
});

var ruleGrid = new Ext.grid.GridPanel({
	frame: true,
	title: 'Rules',
	autoScroll: true,
	store: ruleStore,
	enableHdMenu: false,
	columns: [
	    new Ext.ux.grid.CheckColumn({header: 'Subscribed', width: 20, sortable: true, dataIndex: 'subscribed'}),
		{header: 'Rule', width: 60, sortable: true, dataIndex: 'rule'},
		{header: 'Query', width: 120, sortable: true, dataIndex: 'query', renderer: qtipRenderer}
	],
	tbar: [{
		text: 'Refresh',
		iconCls: 'silk-table-refresh',
		handler: function(b, e) {
			ruleGrid.store.reload();
		}
	}, {
		text: 'Create rule',
		iconCls: 'silk-add',
		handler: function(b, e) {
			ruleWindow.show();
		}
	}, {
		text: 'Subscribe',
		iconCls: 'silk-pencil',
		handler: function(b, e) {
			var s = ruleGrid.getSelectionModel().getSelected();
		    if(s != null)
		    {
		    	ruleSubscribe(s);
		    }
		}
	}, {
		text: 'Unsubscribe',
		iconCls: 'silk-cross',
		handler: function(b, e) {
			var s = ruleGrid.getSelectionModel().getSelected();
		    if(s != null)
		    {
		    	ruleUnsubscribe(s);
		    }
		}
	}],
	viewConfig: {
		forceFit: true
	},
	listeners: {
		celldblclick: function(g, ri, ci, e){
			var s = ruleGrid.store.getAt(ri);
			if(s.data.subscribed){
				ruleUnsubscribe(s);
			}else{
				ruleSubscribe(s);
			}
		},
		cellcontextmenu: function(g, ri, ci, e){
			e.preventDefault();
			ruleGrid.selModel.clearSelections();
			ruleGrid.selModel.selectRow(ri);
			ruleMenu.showAt(e.getXY());
		}
	}
});