Ext.namespace('App.Vops');

var XML_POLICY = 'Policy';
var XML_POLICY_ID = 'PolicyId';
var XML_POLICY_RULE = 'Rule';
var XML_POLICY_RULE_ID = 'RuleId';
var XML_POLICY_TARGET = 'Target';
var XML_POLICY_DESCRIPTION = 'Description';
var XML_POLICY_ACTIONS = 'Actions';
var XML_POLICY_SUBJECTS = 'Subjects';
var XML_POLICY_RESOURCES = 'Resources';

var XML_POLICY_EDITABLE_RULE = 'Rule';
var XML_POLICY_EDITABLE_OBJECTS = new Array('Subjects', 'Resources', 'Actions');
var XML_POLICY_ATTIBUTES = new Array(
	'PolicyId', 
	'RuleCombiningAlgId', 
	'RuleId', 
	'Effect', 
	'DataType', 
	'AttributeId', 
	'MatchId'
);

App.Vops.Data = new Array();
Ext.Ajax.request({
    loadMask: true,
    url: '/vops/policies/constants',
    success: function(response, callOptions) {
		var data = Ext.decode(response.responseText);
		if (data) App.Vops.Data['Constants'] = data;
    }
});

App.Vops.TreeLoader = Ext.extend(Ext.ux.tree.XmlTreeLoader, {
	processAttributes : function(attr) {
		attr.iconCls = 'policy-tree';
		attr.text = attr.tagName;
		attr.loaded = true;
		attr.expanded = false;
		
		switch (attr.tagName) {
			case XML_POLICY:
				attr.iconCls = 'policy-tree-root';
				attr.text = String.format('{0}:{1}', attr.tagName, attr[XML_POLICY_ID]);
				attr.expanded = true;
				break;
			case XML_POLICY_RULE:
				delete attr.iconCls;
				attr.text = String.format('{0}:{1}', attr.tagName, attr[XML_POLICY_RULE_ID]);
				attr.expanded = true;
				break;
			case XML_POLICY_DESCRIPTION:
			case XML_POLICY_TARGET:
				delete attr.iconCls;
				attr.expanded = true;
				break;
			case XML_POLICY_SUBJECTS:
			case XML_POLICY_RESOURCES:
			case XML_POLICY_ACTIONS:
				attr.iconCls = 'policy-tree-list';
				break;
		}
	}
	,loadFromXml: function(xmlString, node, callback) {
	    var xmlData = Sarissa.getDomDocument();
	    xmlData = (new DOMParser()).parseFromString(xmlString, "text/xml");
	    var root = xmlData.documentElement || xmlData;
	
	    try {
	    	this.createNode(root);
	        node.beginUpdate();
	        node.appendChild(this.parseXml(root));
	        node.endUpdate();
	        
            if(typeof callback == "function"){
                callback(this, node);
            }
	    }
	    catch(e){
	        this.handleFailure();
	    }
	}
});

App.Vops.Tree = Ext.extend(Ext.tree.TreePanel, {
    initComponent: function () {
        Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'vops-tree'
        	,autoScroll: true
        	,region: 'west'
            ,containerScroll: true
            ,border: true
            ,animate: true
            ,split: true
            ,width: 420
            ,minSize: 420
            ,margins: '5 0 5 5'
            ,rootVisible: false
            ,loadMask: { msg: "Please wait..." }
            ,root: new Ext.tree.AsyncTreeNode({ expanded: true })
        	,loader: new App.Vops.TreeLoader({ dataUrl: '/vops/policies' })
		    ,tbar: new Ext.Toolbar({
		        items: [
		            {
		                text: 'Add rule'
	                	,iconCls: 'policy-tree-add'
	                	,handler: function() {
		                    var win = new Ext.Window({
		                    	id: 'vops-rule-template-window'
	                    		,title: 'Add rule from template'
								,frame: true
								,modal: true
								,border: false	
		                        ,width: 520
		                        ,items: [
									new Ext.FormPanel({
										id: 'vops-rule-template-window-form'
										,frame: true
										,border: false							
										,labelWidth: 75
										,labelAlign: 'right'
									    ,bodyStyle:'padding:5px'
								    	,defaults: { width: 380 }
									    ,items: [
							             	{
				                                xtype: 'combo'
				                                ,mode: 'local'
			                                	,triggerAction: 'all'
			                                    ,lastQuery: ''
				                                ,allowBlank:false
				                                ,editable: false
				                                ,name: 'template'
				                                ,fieldLabel: 'Template'
			                                	,displayField: 'name'
		                                		,valueField: 'value'
				                                ,store: new Ext.data.JsonStore({
		                                            autoLoad: true
		                                            ,fields: ['name', 'value']
		                                         	,proxy: new Ext.data.HttpProxy({ url: '/vops/policies/templates' })
				                                })
				                            }
									    ]
									})
		                        ]
		                        ,buttons: [
                                    {
		                            	text: 'Create'
	                        			,handler: function() {
                                    		App.Vops.Policies.fireEvent('tree-add-rule-template');
	                            		}
		                        	}
		                        	,{
		                        		text: 'Close'
	                        			,handler: function() {
		                        			Ext.getCmp('vops-rule-template-window').close();
	                            		}
		                        	}
	                        	]
		                    });
		                    
		                    win.show(this);
		            	}
		            }
		            ,{
		                text: 'Reload'
	                	,iconCls: 'policy-tree-reload'
	                	,handler: function() {
		            		App.Vops.Policies.fireEvent('tree-reload');
		            	}
		            }
		            ,'->'
		            ,{
		                text: 'Publish'
	                	,iconCls: 'policy-tree-publish'
	                	,handler: function() {
		            		App.Vops.Policies.fireEvent('tree-publish');
		            	}
		            }
		        ]
		    })
	        ,contextMenu: new Ext.menu.Menu({
	            items: [
                	{
                		id: 'contextmenu-add'
                		,hidden: true
                		,iconCls: 'policy-tree-add'
                		,text: 'Add'
                		,handler : function(item) {
                			App.Vops.Policies.fireEvent('tree-add');
                		}
                	}
                	,{
                		id: 'contextmenu-delete'
            			,hidden: true
            			,text: 'Delete'
            			,iconCls: 'policy-tree-delete'
                		,handler : function(item) {
                			App.Vops.Policies.fireEvent('tree-delete', item);
                		}
                	}
            	]
	        })
        	,listeners: {
                contextmenu: function(node, e) {
        			node.select();
        			
        			if (node.parentNode.getDepth() == 0) {
        				return;	
        			}
        			
                	var isEditable = false;
                	var parent = node.parentNode.parentNode;
                	var c = node.getOwnerTree().contextMenu;
                	
                	c.findById('contextmenu-add').hide();
                	c.findById('contextmenu-delete').hide();
                	
                	if (node.attributes.tagName == XML_POLICY_EDITABLE_RULE) {
                		c.findById('contextmenu-delete').show();
                		isEditable = true;
                	}
                	
                	if (!isEditable) {
	        	    	Ext.each(XML_POLICY_EDITABLE_OBJECTS, function(a) {
	        	        	if (parent.attributes.tagName == a) {
	        	        		var any = 'Any';
	        	        			
	        	        		if (node.attributes.tagName.slice(0, any.length) != any) {
	        	        			c.findById('contextmenu-delete').show();
	        	        			isEditable = true;
	        	        		}
	        	        	}
	        			});
                	}
                	
                	if (!isEditable) {
	        	    	Ext.each(XML_POLICY_EDITABLE_OBJECTS, function(a) {
	        	        	if (node.attributes.tagName == a) {
	        	        		c.findById('contextmenu-add').show();
	        	        		isEditable = true;
	        	        	}
	        			});
                	}

        	    	if (isEditable) {
	                	c.contextNode = node;
	                	c.showAt(e.getXY());
        	    	}
            	}
        	}
        }));

        App.Vops.Tree.superclass.initComponent.apply(this, arguments);
    }
	,export2xml: function(node) {
		if (!node) {
			node = this.getRootNode();
		}
		
	    var result;
	    var tagName = (node.attributes.tagName) ? node.attributes.tagName : 'Policies';
	    
	    result = (node.getDepth() === 0) ? '<?xml version="1.0"?>' : '';
	    result += '<' + tagName;
	    
	    for (var key in node.attributes) {
	    	if (XML_POLICY_ATTIBUTES.indexOf(key) >= 0) {
	    		result += ' ' + key + '="' + node.attributes[key] + '"';
	    	}
	    }
	    
	    var children = node.childNodes;
	    var clen = children.length;
	    result += '>';

        for(var i = 0; i < clen; i++){
            result += this.export2xml(children[i]);
        }
        
        if (node.attributes['innerText'] != undefined) {
        	result += node.attributes['innerText'];
        }
        
        result += '</' + tagName + '>';
	    return result;        
	}
	,clearData: function() {
		var rootNode = this.getRootNode();
		
		while (rootNode.firstChild) {
			rootNode.removeChild(rootNode.firstChild);
		}
	}
	,save: function() {
		var treeXml = this.export2xml();
		
		if (!App.isEmpty(treeXml)) {
	    	Ext.Ajax.request({
			    url: '/vops/policies/save'
			    ,params: { policies: this.export2xml() }
	    		,success: function() {
	        		var tree = App.Vops.Policies.getComponent('vops-tree');
	        		tree.getLoader().load(tree.getRootNode());
	    		}
	    	});
		}
    }
});

App.Vops.Form = Ext.extend(Ext.FormPanel, {
    initComponent: function () {
        Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'vops-form'
    	    ,region: 'center'
    	    ,layout: 'form'
    	    ,margins: '5 5 5 0'
    	    ,disabled: true
        	,autoScroll: true
            ,containerScroll: true
            ,labelWidth: 140
            ,labelAlign: 'right'
            ,bodyStyle: 'padding:15px'
            ,defaults: { anchor: '100%', ctCls: 'policy-form-label' }
            ,defaultType: 'textfield'
            ,plugins:[ new Ext.ux.FormClear() ]
            ,items: {}
		    ,tbar: new Ext.Toolbar({
		        items: [
		            {
		            	text: 'Save'
	                	,iconCls: 'policy-form-save'
	                	,handler: function() {
		            		App.Vops.Policies.fireEvent('form-save');
		            	}
		            }
		            ,{
		                text: 'Cancel'
	                	,iconCls: 'policy-form-cancel'
                		,handler: function() {
		            		App.Vops.Policies.fireEvent('form-cancel');
		            	}
		            }
		        ]
		    })
        }));

        App.Vops.Form.superclass.initComponent.apply(this, arguments);
        this.removeAll(true);
    }
});

App.Vops.Panel = Ext.extend(Ext.Panel, {
    initComponent: function () {
        Ext.apply(this, Ext.apply(this.initialConfig, {
        	id: 'vops'
            ,title: 'Policies'
            ,layout: 'border'
            ,items: [ new App.Vops.Tree(), new App.Vops.Form()	]
        }));

        App.Vops.Panel.superclass.initComponent.apply(this, arguments);
    }
});
